Index: FL/Fl_Text_Display.H
===================================================================
--- FL/Fl_Text_Display.H	(revision 12527)
+++ FL/Fl_Text_Display.H	(working copy)
@@ -293,7 +293,7 @@
    Sets the default font used when drawing text in the widget.
    \param s default text font face
    */
-  void textfont(Fl_Font s) {textfont_ = s; mColumnScale = 0;}
+  void textfont(Fl_Font s) {textfont_ = s; mColumnScale = 0; recalc_display(); }
   
   /**
    Gets the default size of text in the widget.
@@ -305,7 +305,7 @@
    Sets the default size of text in the widget.
    \param s new text size
    */
-  void textsize(Fl_Fontsize s) {textsize_ = s; mColumnScale = 0;}
+  void textsize(Fl_Fontsize s) {textsize_ = s; mColumnScale = 0; recalc_display(); }
   
   /**
    Gets the default color of text in the widget.
@@ -323,6 +323,7 @@
   int wrapped_row(int row) const;
   void wrap_mode(int wrap, int wrap_margin);
   
+  virtual void recalc_display();
   virtual void resize(int X, int Y, int W, int H);
 
   /**
Index: src/Fl_Text_Display.cxx
===================================================================
--- src/Fl_Text_Display.cxx	(revision 12527)
+++ src/Fl_Text_Display.cxx	(working copy)
@@ -212,7 +212,7 @@
 void Fl_Text_Display::linenumber_width(int width) {
   if (width < 0) return;
   mLineNumWidth = width;
-  resize(x(), y(), w(), h());	// triggers code to recalculate line#s
+  recalc_display();		// recalc line#s	// resize(x(), y(), w(), h());
 }
 
 /**
@@ -365,7 +365,7 @@
   }
 
   /* Resize the widget to update the screen... */
-  resize(x(), y(), w(), h());
+  recalc_display();		// resize(x(), y(), w(), h());
 }
 
 
@@ -431,8 +431,6 @@
   return longest;
 }
 
-
-
 /**
  \brief Change the size of the displayed text area.
 
@@ -456,6 +454,13 @@
 #endif // DEBUG2
 
   Fl_Widget::resize(X,Y,W,H);
+  recalc_display();
+}
+
+/**
+ Recalculate the display's visible lines and scrollbar sizes.
+ */
+void Fl_Text_Display::recalc_display() {
   if (!buffer()) return;
 
   // did we have scrollbars initially?
@@ -464,10 +469,10 @@
 
   int oldTAWidth = text_area.w;
 
-  X += Fl::box_dx(box());
-  Y += Fl::box_dy(box());
-  W -= Fl::box_dw(box());
-  H -= Fl::box_dh(box());
+  int X = x() + Fl::box_dx(box());
+  int Y = y() + Fl::box_dy(box());
+  int W = w() - Fl::box_dw(box());
+  int H = h() - Fl::box_dh(box());
 
   text_area.x = X + LEFT_MARGIN + mLineNumWidth;
   text_area.y = Y + TOP_MARGIN;
@@ -680,7 +685,6 @@
 }
 
 
-
 /**
  \brief Refresh a rectangle of the text display.
  \param left, top are in coordinates of the text drawing window.
@@ -941,7 +945,7 @@
     mAbsTopLineNum = 1;		// changed from 0 to 1 -- LZA / STR#2621
   }
 
-  resize(x(), y(), w(), h());
+  recalc_display();		// resize(x(), y(), w(), h());
 }
 
 
@@ -1250,7 +1254,7 @@
  */
 void Fl_Text_Display::show_insert_position() {
   display_insert_position_hint = 1;
-  resize(x(), y(), w(), h());
+  recalc_display();		// resize(x(), y(), w(), h());
 }
 
 
@@ -2817,7 +2821,7 @@
 void Fl_Text_Display::scroll(int topLineNum, int horizOffset) {
   mTopLineNumHint = topLineNum;
   mHorizOffsetHint = horizOffset;
-  resize(x(), y(), w(), h());
+  recalc_display();	// resize(x(), y(), w(), h());
 }
 
 
